==> scummvm_1.7.0+dfsg.orig.tar.xz: scummvm-1.7.0/engines/fullpipe/sound.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#ifndef FULLPIPE_SOUND_H
#define FULLPIPE_SOUND_H

namespace Fullpipe {

class Sound : public MemoryObject {
	int _id;
	char *_description;
	int _directSoundBuffer;
	int _directSoundBuffers[7];
	byte *_soundData;
	Audio::SoundHandle _handle;
	int _volume;

public:
	int16 _objectId;

public:
	Sound();
	virtual ~Sound();

	virtual bool load(MfcArchive &file, NGIArchive *archive);
	virtual bool load(MfcArchive &file) { assert(0); return false; } // Disable base class
	void updateVolume();
	int getId() const { return _id; }
	Audio::SoundHandle getHandle() const { return _handle; }

	void play(int flag);
	void freeSound();
	int getVolume();
	void stop();

	void setPanAndVolumeByStaticAni();
	void setPanAndVolume(int vol, int pan);
};

class SoundList : public CObject {
	Sound **_soundItems;
	int _soundItemsCount;
	NGIArchive *_libHandle;

 public:
	SoundList();
	virtual bool load(MfcArchive &file, char *fname);
	virtual bool load(MfcArchive &file) { assert(0); return false; } // Disable base class
	bool loadFile(const char *fname, char *libname);

	int getCount() { return _soundItemsCount; }
	Sound *getSoundByIndex(int idx) { return _soundItems[idx]; }
	Sound *getSoundItemById(int id);
};

} // End of namespace Fullpipe

#endif /* FULLPIPE_SOUND_H */

==> scummvm_2.1.1+dfsg1.orig.tar.xz: scummvm-2.1.1/engines/fullpipe/sound.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#ifndef FULLPIPE_SOUND_H
#define FULLPIPE_SOUND_H

#include "common/array.h"
#include "common/ptr.h"

namespace Audio {
class SoundHandle;
}

namespace Fullpipe {

class Sound : public MemoryObject {
	int _id;
	int _directSoundBuffer;
	int _directSoundBuffers[7];
	byte *_soundData;
	Audio::SoundHandle *_handle;
	int _volume;

public:
	int16 _objectId;

public:
	Sound();
	virtual ~Sound();

	virtual bool load(MfcArchive &file, NGIArchive *archive);
	virtual bool load(MfcArchive &file) { assert(0); return false; } // Disable base class
	void updateVolume();
	int getId() const { return _id; }
	Audio::SoundHandle *getHandle() const { return _handle; }

	void play(int flag);
	void freeSound();
	int getVolume();
	void stop();

	void setPanAndVolumeByStaticAni();
	void setPanAndVolume(int vol, int pan);
};

class SoundList : public CObject {
	Common::Array<Sound> _soundItems;
	Common::ScopedPtr<NGIArchive> _libHandle;

 public:
	virtual bool load(MfcArchive &file, const Common::String &fname);
	virtual bool load(MfcArchive &file) { assert(0); return false; } // Disable base class
	bool loadFile(const Common::String &fname, const Common::String &libname);

	int getCount() { return _soundItems.size(); }
	Sound &getSoundByIndex(int idx) { return _soundItems[idx]; }
	Sound *getSoundItemById(int id);
};

} // End of namespace Fullpipe

#endif /* FULLPIPE_SOUND_H */
